@@ -38,6 +38,8 @@ def defaultForDatatype(type: DataType):
         return Decimal(0)
     elif isinstance(type, ArrayType):
         return []
+    elif isinstance(type, NullType):
+        return None
     elif isinstance(type, StructType):
         fields = {}
         for field in type.fields:
@@ -73,6 +75,8 @@ def convertStringValueToDatatype(dataType: DataType, value: str):
         newValue = bytearray(0) if isNull(value) else bytearray(value.encode("utf-8"))
     elif isinstance(dataType, BooleanType):
         newValue = False if isNull(value) else (value == "true")
+    elif isinstance(dataType, NullType):
+        newValue = None
     elif isinstance(dataType, DateType):
         newValue = (
             datetime.now() if isNull(value) else datetime.strptime(value, "%Y-%m-%d")
